@@ -4,7 +4,6 @@ package App::Sandy::Base;
 use 5.010;
 use strict;
 use warnings FATAL => 'all';
-no if $] >= 5.018, warnings => "experimental::smartmatch";
 use utf8 ();
 use feature ();
 use true ();
@@ -16,7 +15,7 @@ use Data::OptList;
 use Module::Runtime 'use_module';
 use namespace::autoclean;
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 BEGIN {
 	$SIG{'__DIE__'} = sub {
@@ -66,60 +65,51 @@ sub import {
 	my @no_clean;
 	for my $opt_spec (@opts) {
 		my ($opt, $opt_args) = @$opt_spec;
-		given ($opt) {
-			when ('dont_clean') {
-				if (!$opt_args) {
-					Carp::carp "ignoring dont_clean option without arrayref of subroutine names to keep";
-					next;
-				}
-				push @no_clean, @$opt_args;
+		if ($opt eq 'dont_clean') {
+			if (!$opt_args) {
+				Carp::carp "ignoring dont_clean option without arrayref of subroutine names to keep";
+				next;
 			}
-			when ('class') {
-				require Moose;
-				require MooseX::StrictConstructor;
-				require MooseX::UndefTolerant;
-				require App::Sandy::Types;
-				Moose->import({into=>$caller});
-				MooseX::StrictConstructor->import({into=>$caller});
-				MooseX::UndefTolerant->import({into=>$caller});
-				App::Sandy::Types->import({into=>$caller});
-				after_runtime {
-					$caller->meta->make_immutable;
-				}
+			push @no_clean, @$opt_args;
+		} elsif ($opt eq 'class') {
+			require Moose;
+			require MooseX::StrictConstructor;
+			require MooseX::UndefTolerant;
+			require App::Sandy::Types;
+			Moose->import({into=>$caller});
+			MooseX::StrictConstructor->import({into=>$caller});
+			MooseX::UndefTolerant->import({into=>$caller});
+			App::Sandy::Types->import({into=>$caller});
+			after_runtime {
+				$caller->meta->make_immutable;
 			}
-			when ('role') {
-				require Moose::Role;
-				require App::Sandy::Types;
-				Moose::Role->import({into=>$caller});
-				App::Sandy::Types->import({into=>$caller});
-			}
-			when ('test') {
-				use_module('Test::Most')->import::into($caller);
-				if ($opt_args) {
-					for (@$opt_args) {
-						when ('class_load') {
-							use_module('Test::Class::Load')->import::into($caller, 't/lib');
-						}
-						when ('class_base') {
-							my @classes = qw(Test::Class Class::Data::Inheritable);
-							use_module('base')->import::into($caller, @classes);
-						}
-						default {
-							Carp::carp "Ignoring unknown test option '$_'";
-						}
+		} elsif ($opt eq 'role') {
+			require Moose::Role;
+			require App::Sandy::Types;
+			Moose::Role->import({into=>$caller});
+			App::Sandy::Types->import({into=>$caller});
+		} elsif ($opt eq 'test') {
+			use_module('Test::Most')->import::into($caller);
+			if ($opt_args) {
+				for my $opt_arg (@$opt_args) {
+					if ($opt_arg eq 'class_load') {
+						use_module('Test::Class::Load')->import::into($caller, 't/lib');
+					} elsif ($opt_arg eq 'class_base') {
+						my @classes = qw(Test::Class Class::Data::Inheritable);
+						use_module('base')->import::into($caller, @classes);
+					} else {
+						Carp::carp "Ignoring unknown test option '$_'";
 					}
 				}
 			}
-			default {
-				Carp::carp "Ignoring unknown import option '$_'";
-			}
+		} else {
+			Carp::carp "Ignoring unknown import option '$_'";
 		}
 	}
 
 	#This must come after anything else that might change warning
 	# levels in the caller (e.g. Moose)
 	warnings->import('FATAL'=>'all');
-	warnings->unimport('experimental::smartmatch') if $] >= 5.018;
 
 	namespace::autoclean->import(
 		-cleanee => $caller,
@@ -143,7 +133,7 @@ App::Sandy::Base - Policy and base module to App::Sandy project.
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 AUTHORS
 
@@ -155,11 +145,11 @@ Thiago L. A. Miller <tmiller@mochsl.org.br>
 
 =item *
 
-Gabriela Guardia <gguardia@mochsl.org.br>
+J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
-J. Leonel Buzzo <lbuzzo@mochsl.org.br>
+Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
 
