@@ -3,18 +3,18 @@ package App::Sandy::Command::Expression;
 
 use App::Sandy::Base 'class';
 use App::Sandy::DB::Handle::Expression;
-use Text::SimpleTable::AutoWidth;
+use Text::ASCIITable;
 
 extends 'App::Sandy::CLI::Command';
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 has 'db' => (
 	is         => 'ro',
 	isa        => 'App::Sandy::DB::Handle::Expression',
 	builder    => '_build_db',
 	lazy_build => 1,
-	handles    => [qw/insertdb restoredb deletedb make_report/]
+	handles    => [qw/insertdb restoredb deletedb make_report retrievedb/]
 );
 
 sub _build_db {
@@ -28,7 +28,8 @@ override 'opt_spec' => sub {
 sub subcommand_map {
 	add     => 'App::Sandy::Command::Expression::Add',
 	remove  => 'App::Sandy::Command::Expression::Remove',
-	restore => 'App::Sandy::Command::Expression::Restore'
+	restore => 'App::Sandy::Command::Expression::Restore',
+	dump    => 'App::Sandy::Command::Expression::Dump'
 }
 
 sub validate_args {
@@ -40,16 +41,18 @@ sub execute {
 	my ($self, $opts, $args) = @_;
 
 	my $report_ref = $self->make_report;
-	my $t1 = Text::SimpleTable::AutoWidth->new;
 
-	$t1->captions([qw/expression-matrix source provider date/]);
+	if (%$report_ref) {
+		my $t1 = Text::ASCIITable->new;
+		$t1->setCols('expression-matrix', 'source', 'provider', 'date');
 
-	for my $expression_matrix (sort keys %$report_ref) {
-		my $attr = $report_ref->{$expression_matrix};
-		$t1->row($expression_matrix, $attr->{source}, $attr->{provider}, $attr->{date});
+		for my $expression_matrix (sort keys %$report_ref) {
+			my $attr = $report_ref->{$expression_matrix};
+			$t1->addRow($expression_matrix, $attr->{source}, $attr->{provider}, $attr->{date});
+		}
+
+		print $t1;
 	}
-
-	print $t1->draw;
 }
 
 __END__
@@ -64,7 +67,7 @@ App::Sandy::Command::Expression - expression command class. Manage expression-ma
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -74,10 +77,11 @@ version 0.18
 
  Options:
   -h, --help               brief help message
-  -M, --man                full documentation
+  -u, --man                full documentation
  
  Commands:
   add                      add a new expression-matrix to database
+  dump                     dump an expression-matrix from database
   remove                   remove an user expression-matrix from database
   restore                  restore the database
 
@@ -95,11 +99,11 @@ Thiago L. A. Miller <tmiller@mochsl.org.br>
 
 =item *
 
-Gabriela Guardia <gguardia@mochsl.org.br>
+J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
-J. Leonel Buzzo <lbuzzo@mochsl.org.br>
+Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
 
