@@ -7,16 +7,16 @@ extends 'App::Sandy::CLI::Command';
 
 with 'App::Sandy::Role::Digest';
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
+
 sub default_opt {
-	'paired-end-id'    => '%i.%U_%c %U',
-	'single-end-id'    => '%i.%U_%c %U',
+	'paired-end-id'    => '%i.%U:%c %U',
+	'single-end-id'    => '%i.%U:%c %U',
 	'seed'             => time,
 	'verbose'          => 0,
 	'prefix'           => 'out',
 	'output-dir'       => '.',
 	'jobs'             => 1,
-	'gzip'             => 1,
 	'count-loops-by'   => 'number-of-reads',
 	'number-of-reads'  => 1000000,
 	'strand-bias'      => 'minus',
@@ -24,15 +24,19 @@ sub default_opt {
 	'sequencing-type'  => 'paired-end',
 	'fragment-mean'    => 300,
 	'fragment-stdd'    => 50,
-	'sequencing-error' => 0.005,
-	'read-size'        => 100,
-	'quality-profile'  => 'poisson'
+	'sequencing-error' => 0.001,
+	'read-mean'        => 100,
+	'read-stdd'        => 0,
+	'quality-profile'  => 'poisson',
+	'join-paired-ends' => 0,
+	'output-format'    => 'fastq.gz'
 }
 
 sub rm_opt {
 	'strand-bias',
 	'coverage',
-	'seqid-weight'
+	'seqid-weight',
+	'structural-variation'
 }
 
 __END__
@@ -47,7 +51,7 @@ App::Sandy::Command::Transcriptome - simulate command class. Simulate transcript
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -61,14 +65,15 @@ version 0.18
 
  Options:
   -h, --help                     brief help message
-  -M, --man                      full documentation
+  -u, --man                      full documentation
   -v, --verbose                  print log messages
   -p, --prefix                   prefix output [default:"out"]	
   -o, --output-dir               output directory [default:"."]
+  -O, --output-format            bam, sam, fastq.gz, fastq [default:"fastq.gz"]
+  -1, --join-paired-ends         merge R1 and R2 outputs in one file
   -i, --append-id                append to the defined template id [Format]
   -I, --id                       overlap the default template id [Format]
   -j, --jobs                     number of jobs [default:"1"; Integer]
-  -z, --gzip                     compress output file
   -s, --seed                     set the seed of the base generator
                                  [default:"time()"; Integer]
   -n, --number-of-reads          set the number of reads
@@ -77,14 +82,15 @@ version 0.18
                                  [default:"paired-end"]
   -q, --quality-profile          sequencing system profiles from quality
                                  database [default:"poisson"]
-  -e, --sequencing-error         sequencing error rate
-                                 [default:"0.005"; Number]
-  -r, --read-size                the read size [default:"100"; Integer]
-                                 the quality_profile from database overrides
-                                 this value
-  -m, --fragment-mean            the fragment mean size for paired-end reads
+  -e, --sequencing-error         sequencing error rate for poisson
+                                 [default:"0.001"; Number]
+  -m, --read-mean                read mean size for poisson
+                                 [default:"100"; Integer]
+  -d, --read-stdd                read standard deviation size for poisson
+                                 [default:"0"; Integer]
+  -M, --fragment-mean            the fragment mean size for paired-end reads
                                  [default:"300"; Integer]
-  -d, --fragment-stdd            the fragment standard deviation size for
+  -D, --fragment-stdd            the fragment standard deviation size for
                                  paired-end reads [default:"50"; Integer]
 
 =head1 DESCRIPTION
@@ -116,6 +122,25 @@ Concatenates the prefix to the output-file name.
 Creates output-file inside output-dir. If output-dir
 does not exist, it is created recursively
 
+=item B<--output-format>
+
+Choose the output format. Available options are:
+I<bam>, I<sam>, I<fastq.gz>, I<fastq>.
+For I<bam> option, B<--append-id> is ignored, considering
+that the sequence identifier is splitted by blank character, so
+just the first field is included into the query name column
+(first column).
+
+=item B<--join-paired-ends>
+
+By default, paired-end reads are put into two different files,
+I<prefix_R[12]_001.fastq(\.gz)?>. If the user wants both outputs
+together, she can pass this option.
+If the B<--id> does not have the escape character %R, it is
+automatically included right after the first field (blank separated values)
+as in I<id/%R> - which resolves to I<id/1> or I<id/2>.
+It is necessary to distinguish which read is R1/R2
+
 =item B<--append-id>
 
 Append string template to the defined template id.
@@ -134,46 +159,57 @@ A string B<Format> is a combination of literal and escape characters similar to
 That way, the user has the freedom to customize the fastq sequence identifier to fit her needs. Valid
 escape characteres are:
 
-Common escape characters
+B<Common escape characters>
 
-	Escape       Meaning
-	------       ------------------------------------------
-	%i   	     instrument id composed by SR + PID
-	%I           job slot number
-	%q           quality profile
-	%e           sequencing error
-	%x           sequencing error position
-	%R           read 1, or 2 if it is the paired-end mate
-	%U           read number
-	%r           read size
-	%c           sequence id as chromossome, ref
-	%s           read or fragment strand
-	%t           read start position
-	%n           read end position
+	----------------------------------------------------------------------------
+	 Escape       Meaning
+	----------------------------------------------------------------------------
+	 %i   	      instrument id composed by SR + PID
+	 %I           job slot number
+	 %q           quality profile
+	 %e           sequencing error
+	 %x           sequencing error position
+	 %R           read 1, or 2 if it is the paired-end mate
+	 %U           read number
+	 %r           read size
+	 %m           read mean
+	 %d           read standard deviation
+	 %c           sequence id as chromossome, gene/transcript id
+	 %C           sequence id type (reference or alternate non reference allele) ***
+	 %s           read strand
+	 %t           read start position
+	 %n           read end position
+	 %a           read start position regarding reference genome ***
+	 %b           read end position regarding reference genome ***
+	 %v           structural variation position ***
+	----------------------------------------------------------------------------
+	*** specific for structural variation (genome simulation only)
 
-Paired-end specific escape characters
+B<Paired-end specific escape characters>
 
-	Escape       Meaning
-	------       ------------------------------------------
-	%T           mate read start position
-	%N           mate read end position
-	%D           distance between the paired-reads
-	%m           fragment mean
-	%d           fragment standard deviation
-	%f           fragment size
-	%S           fragment start position
-	%E           fragment end position
+	----------------------------------------------------------------------------
+	 Escape       Meaning
+	----------------------------------------------------------------------------
+	 %T           mate read start position
+	 %N           mate read end position
+	 %A           mate read start position regarding reference genome ***
+	 %B           mate read end position regarding reference genome ***
+	 %D           distance between the paired-reads
+	 %M           fragment mean
+	 %D           fragment standard deviation
+	 %f           fragment size
+	 %F           fragment strand
+	 %S           fragment start position
+	 %E           fragment end position
+	 %X           fragment start position regarding reference genome ***
+	 %Z           fragment end position regarding reference genome ***
+	----------------------------------------------------------------------------
+	*** specific for structural variation (genome simulation only)
 
 =item B<--jobs>
 
 Sets the number of child jobs to be created
 
-=item B<--gzip>
-
-Compress the output-file with gzip algorithm. It is
-possible to pass --no-gzip if one wants
-uncompressed output-file
-
 =item B<--seed>
 
 Sets the seed of the base generator. The ability to set the seed is
@@ -182,11 +218,16 @@ the number of jobs (--jobs) set, because each job receives a different
 seed calculated from the I<main seed>. So, for reproducibility, the
 same seed set before needs the same number of jobs set before as well.
 
-=item B<--read-size>
+=item B<--read-mean>
 
-Sets the read size, if quality-profile is equal to 'poisson'. The
+Sets the read mean if quality-profile is equal to 'poisson'. The
 quality-profile from database overrides the read-size
 
+=item B<--read-stdd>
+
+Sets the read standard deviation if quality-profile is equal to
+'poisson'. The quality-profile from database overrides the read-stdd
+
 =item B<--number-of-reads>
 
 Sets the number of reads desired. This is the default option
@@ -208,7 +249,8 @@ fragment standard deviation
 
 =item B<--sequencing-error>
 
-Sets the sequencing error rate. Valid values are between zero and one
+Sets the sequencing error rate if quality-profile is equal to 'poisson'.
+Valid values are between zero and one
 
 =item B<--quality-profile>
 
@@ -234,11 +276,11 @@ Thiago L. A. Miller <tmiller@mochsl.org.br>
 
 =item *
 
-Gabriela Guardia <gguardia@mochsl.org.br>
+J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
-J. Leonel Buzzo <lbuzzo@mochsl.org.br>
+Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
 
