@@ -5,26 +5,26 @@ use App::Sandy::Base 'class';
 
 extends 'App::Sandy::Read';
 
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 sub gen_read {
-	my ($self, $seq_ref, $seq_size, $is_leader) = @_;
+	my ($self, $ptable, $ptable_size, $read_size, $is_leader) = @_;
 
-	if ($seq_size < $self->read_size) {
-		die sprintf "seq_size (%d) must be greater or equal to read_size (%d)\n"
-			=> $seq_size, $self->read_size;
+	if ($ptable_size < $read_size) {
+		croak sprintf "ptable_size (%d) must be greater or equal to read_size (%d)"
+			=> $ptable_size, $read_size;
 	}
 
-	my ($read_ref, $read_pos) = $self->subseq_rand($seq_ref, $seq_size, $self->read_size);
+	my ($read_ref, $attr) = $self->subseq_rand_ptable($ptable,
+		$ptable_size, $read_size, $read_size);
 
 	unless ($is_leader) {
 		$self->reverse_complement($read_ref);
 	}
 
-	$self->update_count_base($self->read_size);
-	my $errors_a = $self->insert_sequencing_error($read_ref);
+	$attr->{error} = $self->insert_sequencing_error($read_ref, $read_size);
 
-	return ($read_ref, $read_pos, $errors_a);
+	return ($read_ref, $attr);
 }
 
 __END__
@@ -39,7 +39,7 @@ App::Sandy::Read::SingleEnd - App::Sandy::Read subclass for simulate single-end
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 AUTHORS
 
@@ -51,11 +51,11 @@ Thiago L. A. Miller <tmiller@mochsl.org.br>
 
 =item *
 
-Gabriela Guardia <gguardia@mochsl.org.br>
+J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
-J. Leonel Buzzo <lbuzzo@mochsl.org.br>
+Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
 
